@@ -9,6 +9,7 @@ use Ixchel::functions::file_get;
 use utf8;
 use File::Temp qw/ tempfile tempdir /;
 use File::Spec;
+use base 'Ixchel::Actions::base';
 
 =head1 NAME
 
@@ -16,13 +17,17 @@ Ixchel::Actions::sagan_base - Generates the base config for a sagan instance.
 
 =head1 VERSION
 
-Version 0.1.1
+Version 0.2.0
 
 =cut
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.2.0';
 
-=head1 SYNOPSIS
+=head1 CLI SYNOPSIS
+
+ixchel -a sagan_base [B<-w>] [B<-i> <instance>]
+
+=head1 CODE SYNOPSIS
 
     use Data::Dumper;
 
@@ -51,10 +56,6 @@ instance setups if .sagan.multi_instance is set to 1 then
 
 =head1 FLAGS
 
-=head2 --np
-
-Do not print the status of it.
-
 =head2 -w
 
 Write the generated services to service files.
@@ -71,59 +72,11 @@ A instance to operate on.
 
 =cut
 
-sub new {
-	my ( $empty, %opts ) = @_;
+sub new_extra { }
 
-	my $self = {
-		config => {},
-		vars   => {},
-		arggv  => [],
-		opts   => {},
-	};
-	bless $self;
-
-	if ( defined( $opts{config} ) ) {
-		$self->{config} = $opts{config};
-	}
-
-	if ( defined( $opts{t} ) ) {
-		$self->{t} = $opts{t};
-	} else {
-		die('$opts{t} is undef');
-	}
-
-	if ( defined( $opts{share_dir} ) ) {
-		$self->{share_dir} = $opts{share_dir};
-	}
-
-	if ( defined( $opts{opts} ) ) {
-		$self->{opts} = \%{ $opts{opts} };
-	}
-
-	if ( defined( $opts{argv} ) ) {
-		$self->{argv} = $opts{argv};
-	}
-
-	if ( defined( $opts{vars} ) ) {
-		$self->{vars} = $opts{vars};
-	}
-
-	if ( defined( $opts{ixchel} ) ) {
-		$self->{ixchel} = $opts{ixchel};
-	}
-
-	return $self;
-} ## end sub new
-
-sub action {
+sub action_extra {
 	my $self = $_[0];
 
-	my $results = {
-		errors      => [],
-		status_text => '',
-		ok          => 0,
-	};
-
 	my $config_base = $self->{config}{sagan}{config_base};
 
 	my $have_config = 0;
@@ -133,36 +86,68 @@ sub action {
 		my $parsed_yaml;
 		$fetched_raw_yaml = file_get( url => $self->{config}{sagan}{base_config} );
 		if ( !defined($fetched_raw_yaml) ) {
-			die('file_get returned undef');
+			$self->status_add( error => 1, status_add => 'file_get returned undef' );
+			return undef;
 		}
 		utf8::encode($fetched_raw_yaml);
 		$parsed_yaml = Load($fetched_raw_yaml);
 		if ( !defined($parsed_yaml) ) {
-			die('Attempting to parse the returned data as YAML failed');
+			$self->status_add( error => 1, status_add => 'Attempting to parse the returned data as YAML failed' );
+			return undef;
 		}
 
-		write_file( $tmp_file, $fetched_raw_yaml );
+		eval { write_file( $tmp_file, $fetched_raw_yaml ); };
+		if ($@) {
+			$self->status_add(
+				error      => 1,
+				status_add => 'Failed to write out tmp file to "' . $tmp_file . '" ...'
+			);
+			return undef;
+		}
 
 		# removes array based items that are problematic to deal with
-		system( 'yq', '-i', 'del(.rules-files)', $tmp_file );
+		my $output = `yq -i  'del(.rules-files)' $tmp_file 2>&1`;
 		if ( $? ne 0 ) {
-			die( 'Fetched YAML saved to "' . $tmp_file . '" and could not be parsed by yq to delete .rules-files' );
-		}
-		system( 'yq', '-i', 'del(.outputs)', $tmp_file );
+			$self->status_add(
+				error      => 1,
+				status_add => 'Fetched YAML saved to "'
+					. $tmp_file
+					. '" and could not be parsed by yq to delete .rules-files ... '
+					. $output
+			);
+			return undef;
+		} ## end if ( $? ne 0 )
+		$output = `yq -i 'del(.outputs)' $tmp_file 2>&1`;
 		if ( $? ne 0 ) {
-			die( 'Fetched YAML saved to "' . $tmp_file . '" and could not be parsed by yq to delete .outputs' );
-		}
-		system( 'yq', '-i', 'del(.processors)', $tmp_file );
+			$self->status_add(
+				error      => 1,
+				status_add => 'Fetched YAML saved to "'
+					. $tmp_file
+					. '" and could not be parsed by yq to delete .outputs ... '
+					. $output
+			);
+			return undef;
+		} ## end if ( $? ne 0 )
+		$output = `yq -i 'del(.processors)' $tmp_file`;
 		if ( $? ne 0 ) {
-			die( 'Fetched YAML saved to "' . $tmp_file . '" and could not be parsed by yq to delete .processors' );
-		}
+			$self->status_add(
+				error      => 1,
+				status_add => 'Fetched YAML saved to "'
+					. $tmp_file
+					. '" and could not be parsed by yq to delete .processors ... '
+					. $output
+			);
+			return undef;
+		} ## end if ( $? ne 0 )
 
 		$have_config = 1;
 	};
 	if ($@) {
-		my $error = 'Fetching ' . $self->{config}{sagan}{base_config} . ' failed... ' . $@;
-		push( @{ $results->{errors} }, $error );
-		$results->{status_text} = '# ' . $error . "\n";
+		$self->status_add(
+			error      => 1,
+			status_add => 'Fetching ' . $self->{config}{sagan}{base_config} . ' failed... ' . $@
+		);
+		return undef;
 	}
 
 	if ($have_config) {
@@ -191,24 +176,23 @@ sub action {
 						write_file( $config_file, $raw_yaml );
 					}
 
-					$results->{status_text}
-						= $results->{status_text}
-						. '-----[ Instance '
-						. $instance
-						. ' ]-------------------------------------' . "\n"
-						. $raw_yaml . "\n";
+					$self->status_add( status_add => '-----[ Instance '
+							. $instance
+							. ' ]-------------------------------------' . "\n"
+							. $raw_yaml
+							. "\n" );
 				};
 				if ($@) {
-					$results->{status_text}
-						= $results->{status_text}
-						. '-----[ Error: Instance '
-						. $instance
-						. ' ]-------------------------------------' . "\n";
-
-					my $error = 'Writing ' . $config_file . ' failed... ' . $@;
-					push( @{ $results->{errors} }, $error );
-					$results->{status_text} = $results->{status_text} . '# ' . $error . "\n";
-					$self->{ixchel}{errors_count}++;
+					$self->status_add(
+						error      => 1,
+						status_add => '-----[ Error: Instance '
+							. $instance
+							. ' ]-------------------------------------'
+							. "\nWriting "
+							. $config_file
+							. ' failed... '
+							. $@
+					);
 				} ## end if ($@)
 			} ## end foreach my $instance (@instances)
 		} else {
@@ -227,31 +211,28 @@ sub action {
 					write_file( $config_file, $raw_yaml );
 				}
 
-				$results->{status_text} = $results->{status_text} . $raw_yaml;
+				$self->status_add(
+					status_add => "\n" . $raw_yaml
+
+				);
 			};
 			if ($@) {
-				my $error = 'Writing ' . $config_file . ' failed... ' . $@;
-				push( @{ $results->{errors} }, $error );
-				$results->{status_text} = $results->{status_text} . '# ' . $error . "\n";
-				$self->{ixchel}{errors_count}++;
+				$self->status_add(
+					status_add => 'Writing ' . $config_file . ' failed... ' . $@,
+					error      => 1,
+				);
 			}
 		} ## end else [ if ( $self->{config}{sagan}{multi_instance...})]
 	} ## end if ($have_config)
 
-	if ( !$self->{opts}{np} ) {
-		print $results->{status_text};
-	}
+	eval { unlink($tmp_file); };
+	$self->status_add(
+		status_add => 'Unlinkg tmp file, "' . $tmp_file . '" failed ... ' . $@,
+		error      => 1,
+	);
 
-	if ( !defined( $self->{results}{errors}[0] ) ) {
-		$self->{results}{ok} = 1;
-	} else {
-		$self->{results}{ok} = 0;
-	}
-
-	unlink($tmp_file);
-
-	return $results;
-} ## end sub action
+	return undef;
+} ## end sub action_extra
 
 sub short {
 	return 'Generates the base config for a sagan instance.';
@@ -259,7 +240,6 @@ sub short {
 
 sub opts_data {
 	return 'i=s
-np
 w
 ';
 }
